@@ -1,11 +1,14 @@
-from collective.collectionfilter.interfaces import IGroupByCriteria, IGroupByModifier
-from collective.taxonomy import PATH_SEPARATOR, PRETTY_PATH_SEPARATOR, utility
+from collective.collectionfilter.interfaces import IGroupByCriteria
+from collective.collectionfilter.interfaces import IGroupByModifier
+from collective.taxonomy import PATH_SEPARATOR
+from collective.taxonomy import PRETTY_PATH_SEPARATOR
+from collective.taxonomy import utility
 from collective.taxonomy.interfaces import ITaxonomy
 from plone import api
 from plone.behavior.interfaces import IBehavior
 from zope.component import adapter
-from zope.component.hooks import getSite
 from zope.component import queryUtility
+from zope.component.hooks import getSite
 from zope.interface import implementer
 
 
