@@ -1,17 +1,14 @@
-# -*- coding: utf-8 -*-
 from Acquisition import aq_parent
+from collections.abc import Iterable
+from collective.taxonomy.interfaces import ITaxonomy
 from plone import api
-from plone.indexer.interfaces import IIndexer
 from plone.dexterity.interfaces import IDexterityContent
-
+from plone.indexer.interfaces import IIndexer
 from Products.CMFPlone.interfaces import IPloneSiteRoot
 from Products.ZCatalog.interfaces import IZCatalog
-from zope.component import adapts
+from zope.component import adapter
 from zope.interface import implementer
 
-from collective.taxonomy.interfaces import ITaxonomy
-
-import collections
 import logging
 import six
 
@@ -46,7 +43,7 @@ class TaxonomyIndexerWrapper(object):
 
         found = []
         stored_element = getattr(self.context, self.field_name)
-        if not isinstance(stored_element, collections.Iterable) or isinstance(
+        if not isinstance(stored_element, Iterable) or isinstance(
             stored_element, six.string_types
         ):
             stored_element = [stored_element]
@@ -75,12 +72,11 @@ class TaxonomyIndexerWrapper(object):
         return result
 
 
+@adapter(IDexterityContent, IZCatalog)
 @implementer(IIndexer)
 class TaxonomyIndexer(object):
     __name__ = "TaxonomyIndexer"
 
-    adapts(IDexterityContent, IZCatalog)
-
     def __init__(self, field_name, utility_name):
         self.field_name = field_name
         self.utility_name = utility_name
