@@ -2,15 +2,16 @@ import React, { PropTypes } from 'react';
 import { FormattedMessage } from 'react-intl';
 
 const HideTreeCheckbox = ({ onChange }) => (
-  <div className="field">
+  <div className="form-check mb-3">
     <input
       type="checkbox"
       id="toggle-view-tree"
+      className="form-check-input"
       name="toggle-view-tree"
       onChange={onChange}
     />
     &nbsp;
-    <label htmlFor="toggle-view-tree">
+    <label htmlFor="toggle-view-tree" className="form-check-label">
       <FormattedMessage
         id="showViewTree"
         defaultMessage="Show the taxonomy in another language to compare"
