@@ -1,9 +1,5 @@
 # -*- coding: utf-8 -*-
-import json
-import os
-
 from BTrees.OOBTree import OOBTree
-from Products.Five.browser import BrowserView
 from collective.taxonomy import PATH_SEPARATOR
 from collective.taxonomy.i18n import CollectiveTaxonomyMessageFactory as _
 from collective.taxonomy.interfaces import ITaxonomy
@@ -11,9 +7,13 @@ from collective.taxonomy.vdex import TreeExport
 from lxml import etree
 from plone import api
 from plone.app.vocabularies.language import AvailableContentLanguageVocabularyFactory
+from Products.Five.browser import BrowserView
 from zope.component import queryUtility
 from zope.i18n import translate
 
+import json
+import os
+
 
 class EditTaxonomyData(TreeExport, BrowserView):
     """Taxonomy tree edit view."""
@@ -143,7 +143,7 @@ class ImportJson(BrowserView):
         for item in parsed_data:
             new_key = item["key"]
             title = item["translations"].get(language, "")
-            new_path = u"{}{}".format(path, title)
+            new_path = "{}{}".format(path, title)
             result.append(
                 (
                     new_path,
@@ -152,7 +152,7 @@ class ImportJson(BrowserView):
             )
             subnodes = item.get("subnodes", [])
             if subnodes:
-                new_path = u"{}{}".format(new_path, PATH_SEPARATOR)
+                new_path = "{}{}".format(new_path, PATH_SEPARATOR)
                 result.extend(
                     self.generate_data_for_taxonomy(subnodes, language, new_path)
                 )
