@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-import unittest
-
 from collective.taxonomy.interfaces import ITaxonomy
 from collective.taxonomy.testing import INTEGRATION_TESTING
 from zope.component import queryUtility
 
+import unittest
+
 
 class TestUtility(unittest.TestCase):
     layer = INTEGRATION_TESTING
@@ -14,5 +14,5 @@ class TestUtility(unittest.TestCase):
         self.assertIsNotNone(taxonomy)
 
         tree = taxonomy.makeVocabulary("en").makeTree()
-        self.assertIn(u"Information Science", tree)
-        self.assertEqual(len(tree[u"Information Science"]), 4)
+        self.assertIn("Information Science", tree)
+        self.assertEqual(len(tree["Information Science"]), 4)
